@@ -1,3 +1,3 @@
 from tapioca_arbache.tapioca_arbache import (
-    PerfilClient, OauthClient
-)
\ No newline at end of file
+    PerfilClient, OauthClient, LicencaClient
+)
